'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = buildQueryTree;

var _graphql = require('graphql');

var _values = require('graphql/execution/values');

function buildQueryTree(info) {
  let keepRoot = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;

  let tree = buildTree(info.fieldNodes, info.parentType, info);
  if (!keepRoot) {
    tree = tree[info.fieldName];
  }
  return tree;
}

const buildTree = function (selections, parentType, info) {
  let tree = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

  parentType = getType(parentType);
  const fields = selectionsToFields(selections, info);
  fields.forEach(field => {
    const name = field.name.value;
    tree[name] = {};
    const fieldDef = parentType._fields[name];
    tree[name]['$args'] = (0, _values.getArgumentValues)(fieldDef, field, info.variableValues);
    if (field.selectionSet) {
      buildTree(field.selectionSet.selections, fieldDef.type, info, tree[name]);
    }
  });
  return tree;
};

const getType = function (type) {
  type = (0, _graphql.getNullableType)(type);
  if (type.ofType) {
    type = getType(type.ofType);
  }
  return type;
};

const selectionsToFields = function (selections, info) {
  const fields = [];
  selections.forEach(sel => {
    if (sel.kind === 'Field') {
      fields.push(sel);
    } else if (sel.kind === 'FragmentSpread') {
      const fragment = info.fragments[sel.name.value];
      fields.push.apply(fields, selectionsToFields(fragment.selectionSet.selections));
    } else if (sel.kind === 'InlineFragment') {
      fields.push.apply(fields, selectionsToFields(sel.selectionSet.selections));
    }
  });
  return fields;
};